summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/H5P.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/H5P.c b/src/H5P.c
index 357fccc..916fab8 100644
--- a/src/H5P.c
+++ b/src/H5P.c
@@ -2584,10 +2584,10 @@ H5Pset_gc_references(hid_t fapl_id, unsigned gc_ref)
/*-------------------------------------------------------------------------
- * Function: H5Pget_gc_refernces
+ * Function: H5Pget_gc_references
*
* Purpose: Returns the current setting for the garbage collection
* refernces property from a file access property list.
*
* Return: Non-negative on success/Negative on failure
*
@@ -2599,11 +2599,11 @@ H5Pset_gc_references(hid_t fapl_id, unsigned gc_ref)
*-------------------------------------------------------------------------
*/
herr_t
-H5Pget_gc_reference(hid_t fapl_id, unsigned *gc_ref/*out*/)
+H5Pget_gc_references(hid_t fapl_id, unsigned *gc_ref/*out*/)
{
H5F_access_t *fapl = NULL;
- FUNC_ENTER(H5Pget_gc_reference, FAIL);
+ FUNC_ENTER(H5Pget_gc_references, FAIL);
H5TRACE2("e","ix",fapl_id,gc_ref);
/* Check args */
@@ -2584,10 +2584,10 @@ H5Pset_gc_references(hid_t fapl_id, unsigned gc_ref)
*
* Purpose: Returns the current setting for the garbage collection
- * refernces property from a file access property list.
+ * references property from a file access property list.
*
* Return: Non-negative on success/Negative on failure